Rename key to name in fuzztest SetEnv()

[skip ci]
diff --git a/tests/gtest/avif_fuzztest_helpers.cc b/tests/gtest/avif_fuzztest_helpers.cc
index 944e0cf..876008b 100644
--- a/tests/gtest/avif_fuzztest_helpers.cc
+++ b/tests/gtest/avif_fuzztest_helpers.cc
@@ -200,15 +200,16 @@
 namespace {
 class Environment : public ::testing::Environment {
  public:
-  Environment(const char* key, const char* value) : key_(key), value_(value) {}
-  void SetUp() override { setenv(key_, value_, 1); }
-  const char* key_;
+  Environment(const char* name, const char* value)
+      : name_(name), value_(value) {}
+  void SetUp() override { setenv(name_, value_, 1); }
+  const char* name_;
   const char* value_;
 };
 }  // namespace
 
-::testing::Environment* SetEnv(const char* key, const char* value) {
-  return ::testing::AddGlobalTestEnvironment(new Environment(key, value));
+::testing::Environment* SetEnv(const char* name, const char* value) {
+  return ::testing::AddGlobalTestEnvironment(new Environment(name, value));
 }
 
 //------------------------------------------------------------------------------
diff --git a/tests/gtest/avif_fuzztest_helpers.h b/tests/gtest/avif_fuzztest_helpers.h
index 3f719f4..47a7cce 100644
--- a/tests/gtest/avif_fuzztest_helpers.h
+++ b/tests/gtest/avif_fuzztest_helpers.h
@@ -187,10 +187,9 @@
 //------------------------------------------------------------------------------
 // Environment setup
 
-// Sets the environment variable 'key' to the 'value'.
-::testing::Environment* SetEnv(const char* key, const char* value);
+// Sets the environment variable 'name' to the 'value' during the setup step.
+::testing::Environment* SetEnv(const char* name, const char* value);
 
-// Sets the FUZZTEST_STACK_LIMIT environment variable to 524288.
 inline ::testing::Environment* SetStackLimitTo512x1024Bytes() {
   return SetEnv("FUZZTEST_STACK_LIMIT", "524288");
 }